@@ -355,6 +355,8 @@ class ApiManager:
                             )
                         )
 
+                        self.sources.wait_for_dataset(org_id=org_id,dataset_id=new_source["data_set_id"])
+
                         source_to_import["new_source_id"] = new_source["data_set_id"]
 
                         msg.append("DataSource '{}' imported successfully".format(source_to_import["name"]))
@@ -376,6 +378,8 @@ class ApiManager:
                             org_id=org_id
                         )
 
+                        self.sources.wait_for_dataset(org_id=org_id, dataset_id=new_source["id"])
+
                         source_to_import["new_source_id"] = new_source["id"]
 
                         already_created_by_name[source_to_import["name"]] = new_source["id"]
@@ -407,6 +411,8 @@ class ApiManager:
                             org_id=org_id
                         )
 
+                        self.sources.wait_for_dataset(org_id=org_id, dataset_id=new_source["id"])
+
                         source_to_import["new_source_id"] = new_source["id"]
 
                         already_created_by_name[source_to_import["name"]] = new_source["id"]
@@ -994,6 +1000,11 @@ class ApiManager:
 
             created_pipeline_id = pipeline['pipeline']['id']
 
+            self.pipelines.wait_for_pipeline(
+                org_id=org_id,
+                pipeline_id=created_pipeline_id
+            )
+
             self.pipelines.update_pipeline_from_json(
                 org_id=org_id,
                 update_payload=data["pipeline"]["pipeline"]["data"],
