@@ -313,6 +313,36 @@ class OrgAdmin(ApiRequestManager):
         except Exception as error:
             raise error
 
+    @single_org
+    def extend_expiration(self, org_id=None, *, days):
+        """
+        Extend organization time
+
+        :param org_id: Org id to rename
+        :param days: Days until org expires
+        :return:
+        """
+
+        header = self.build_header(
+            others=self.content_type_header
+        )
+
+        organization_url = self.org_api_url.format(org_id)
+
+        payload = {"id": org_id, "expiry": days}
+
+        try:
+
+            request = self.session.put(organization_url, data=json.dumps(payload), headers=header)
+
+            if request.status_code in [200, 201]:
+                return json.loads(request.content)
+
+            raise Exception(request.content)
+
+        except Exception as error:
+            raise error
+
     def move_user_to_group(self, user_id, group_id):
         """
         Change user to a given group
